struct ColorProfile {
rgb: ColorProfile,
}Expand description
An RGB profile with its related (same tone-mapping) gray profile.
This is the whole input information which we must be able to pass to the CMS in a support
transform, to handle all possible combinations of ColorType pixels that can be thrown at us.
For instance, in a previous iteration we had a separate gray profile here (but now handle that
internally by expansion to RGB through an YCbCr). Future iterations may add additional structs
to be computed for validating CicpTransform::new.
Fields
rgb: ColorProfileImplementations
Sourceimpl ColorProfile
impl ColorProfile
fn map_layout(&self, layout: LayoutWithColor) -> (&ColorProfile, Layout)